<?php

/**
 * @file
 * Contains \Drupal\pgn\Tests\PgnEncoderUnitTest.
 */

namespace Drupal\pgn\Tests;

use Drupal\pgn\Serializer\Encoder\PgnEncoder;

/**
 * Tests the PGN Encoder.
 */
class PgnEncoderUnitTest extends \DrupalUnitTestCase {

  protected $encoder;

  /**
   * {@inheritdoc}
   */
  public static function getInfo() {
    return array(
      'name' => 'PGN Encoder test',
      'description' => 'Test that PGN Encoder encodes into PGN.',
      'group' => 'PGN',
    );
  }

  /**
   * {@inheritdoc}
   */
  protected function setUp() {
    $module_directory_path = dirname(substr(__DIR__, 0, -strlen(__NAMESPACE__)));
    require_once $module_directory_path . '/vendor/symfony/serializer/Symfony/Component/Serializer/Encoder/EncoderInterface.php';
    require_once $module_directory_path . '/lib/Drupal/pgn/Serializer/Encoder/PgnEncoder.php';
    $this->encoder = new PgnEncoder();
    parent::setUp();
  }

  /**
   * @test
   * @dataProvider providerPgnEncode
   */
  public function pgnEncode($normalized, $file) {
    $encoded = $this->encoder->encode($normalized, 'pgn');

    $module_directory_path = dirname(substr(__DIR__, 0, -strlen(__NAMESPACE__)));
    $expected = file_get_contents($module_directory_path . '/tests/' . $file);
    $this->assertEqual($expected, $encoded, $expected . ' should equal ' . $encoded);
  }

  public function providerPgnEncode() {
    return array(
      array(
        array(
          array(
            'tags' => array(
              'Event' => '?',
              'Site' => '?',
              'Date' => '????.??.??',
              'Round' => '?',
              'White' => '?',
              'Black' => '?',
              'Result' => '*',
            ),
            'movetext' => array(
              1 => array('e4', 'f5'),
              2 => array('Qh5+'),
            ),
          ),
          array(
            'tags' => array(
              'Event' => '?',
              'Site' => '?',
              'Date' => '????.??.??',
              'Round' => '?',
              'White' => '?',
              'Black' => '?',
              'Result' => '*',
            ),
            'movetext' => array(
              1 => array('e4', 'f5'),
              2 => array('Qh5+'),
            ),
          ),
        ),
        'e4f5Dh5.pgn',
      ),
    );
  }

  public function testPgnEncode() {
    foreach ($this->providerPgnEncode() as $data) {
      call_user_func_array(array($this, 'pgnEncode'), $data);
    }
  }

}
